@@ -24,7 +24,6 @@
 
 #include <glib/gi18n.h>
 
-#include "vinagre-util.h"
 #include "vinagre-dnd.h"
 #include "vinagre-prefs.h"
 
@@ -511,45 +510,50 @@ static GtkWidget *
 build_tab_label (VinagreNotebook *nb, 
 		 VinagreTab      *tab)
 {
-  GtkWidget *hbox, *label_hbox, *label_ebox;
+  GtkWidget *box, *label_box, *label_ebox;
   GtkWidget *label, *dummy_label;
   GtkWidget *close_button, *spinner;
-  GtkRcStyle *rcstyle;
   GtkWidget *image;
   GtkWidget *icon;
   gchar     *name;
+    GtkStyleContext *context;
+    GtkCssProvider *css;
 
-  hbox = gtk_hbox_new (FALSE, 4);
+    static const gchar button_style[] = "* {\n"
+        "-GtkButton-default-border : 0;\n"
+        "-GtkButton-default-outside-border : 0;\n"
+        "-GtkButton-inner-border: 0;\n"
+        "-GtkWidget-focus-line-width : 0;\n"
+        "-GtkWidget-focus-padding : 0;\n"
+        "padding: 0;\n"
+        "}";
+
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
   label_ebox = gtk_event_box_new ();
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (label_ebox), FALSE);
-  gtk_box_pack_start (GTK_BOX (hbox), label_ebox, TRUE, TRUE, 0);
-  gtk_widget_set_tooltip_text (label_ebox, _("Connecting..."));
+  gtk_box_pack_start (GTK_BOX (box), label_ebox, TRUE, TRUE, 0);
+  gtk_widget_set_tooltip_text (label_ebox, _("Connecting…"));
 
-  label_hbox = gtk_hbox_new (FALSE, 4);
-  gtk_container_add (GTK_CONTAINER (label_ebox), label_hbox);
+  label_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  gtk_container_add (GTK_CONTAINER (label_ebox), label_box);
 
-  /* setup close button */
-  close_button = gtk_button_new ();
-  gtk_button_set_relief (GTK_BUTTON (close_button),
-			 GTK_RELIEF_NONE);
+    /* setup close button */
+    close_button = gtk_button_new ();
+    css = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (css, button_style, -1, NULL);
+    context = gtk_widget_get_style_context (close_button);
+    gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (css),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
 
   /* don't allow focus on the close button */
   gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
 
   /* make it as small as possible */
-  rcstyle = gtk_rc_style_new ();
-  rcstyle->xthickness = rcstyle->ythickness = 0;
-  gtk_widget_modify_style (close_button, rcstyle);
-  g_object_unref (rcstyle);
-  gint w, h;
-  gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
-  gtk_widget_set_size_request (GTK_WIDGET (close_button), w+2, h+2);
-
-  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
+  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
   gtk_container_add (GTK_CONTAINER (close_button), image);
-  gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (box), close_button, FALSE, FALSE, 0);
 
   gtk_widget_set_tooltip_text (close_button, _("Close connection"));
 
@@ -560,12 +564,12 @@ build_tab_label (VinagreNotebook *nb,
 
   /* setup spinner */
   spinner = gtk_spinner_new();
-  gtk_box_pack_start (GTK_BOX (label_hbox), spinner, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (label_box), spinner, FALSE, FALSE, 0);
 
   /* setup site icon */
   icon = gtk_image_new_from_icon_name (vinagre_tab_get_icon_name (tab),
 				       GTK_ICON_SIZE_MENU);
-  gtk_box_pack_start (GTK_BOX (label_hbox), icon, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (label_box), icon, FALSE, FALSE, 0);
 	
   /* setup label */
   name = vinagre_connection_get_best_name (vinagre_tab_get_conn (tab));
@@ -573,39 +577,39 @@ build_tab_label (VinagreNotebook *nb,
   g_free (name);
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_misc_set_padding (GTK_MISC (label), 0, 0);
-  gtk_box_pack_start (GTK_BOX (label_hbox), label, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (label_box), label, FALSE, FALSE, 0);
 
   dummy_label = gtk_label_new ("");
-  gtk_box_pack_start (GTK_BOX (label_hbox), dummy_label, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (label_box), dummy_label, TRUE, TRUE, 0);
 	
-  gtk_widget_show (hbox);
+  gtk_widget_show (box);
   gtk_widget_show (label_ebox);
-  gtk_widget_show (label_hbox);
+  gtk_widget_show (label_box);
   gtk_widget_show (label);
   gtk_widget_show (dummy_label);	
   gtk_widget_show (image);
   gtk_widget_show (close_button);
   
-  g_object_set_data (G_OBJECT (hbox), "label", label);
+  g_object_set_data (G_OBJECT (box), "label", label);
   g_object_set_data (G_OBJECT (tab),  "label", label);
-  g_object_set_data (G_OBJECT (hbox), "label-ebox", label_ebox);
+  g_object_set_data (G_OBJECT (box), "label-ebox", label_ebox);
   g_object_set_data (G_OBJECT (tab),  "label-ebox", label_ebox);
   g_object_set_data (G_OBJECT (tab), "spinner", spinner);
   g_object_set_data (G_OBJECT (tab), "icon", icon);
-  g_object_set_data (G_OBJECT (hbox), "close-button", close_button);
+  g_object_set_data (G_OBJECT (box), "close-button", close_button);
   g_object_set_data (G_OBJECT (tab),  "close-button", close_button);
 
-  gtk_drag_source_set ( GTK_WIDGET (hbox),
+  gtk_drag_source_set ( GTK_WIDGET (box),
 			GDK_BUTTON1_MASK,
 			vinagre_target_list,
 			G_N_ELEMENTS (vinagre_target_list),
 			GDK_ACTION_COPY );
-  g_signal_connect (hbox,
+  g_signal_connect (box,
 		    "drag-data-get",
 		    G_CALLBACK (drag_data_get_handl),
 		    tab);
 
-  return hbox;
+  return box;
 }
 
 void
