@@ -49,7 +49,7 @@ struct _VinagreTabPrivate
   gboolean          has_screenshot;
 };
 
-G_DEFINE_ABSTRACT_TYPE (VinagreTab, vinagre_tab, GTK_TYPE_VBOX)
+G_DEFINE_ABSTRACT_TYPE (VinagreTab, vinagre_tab, GTK_TYPE_BOX)
 
 /* Signals */
 enum
@@ -546,6 +546,8 @@ vinagre_tab_add_recent_used (VinagreTab *tab)
 static void
 vinagre_tab_init (VinagreTab *tab)
 {
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (tab), GTK_ORIENTATION_VERTICAL);
+
   tab->priv = VINAGRE_TAB_GET_PRIVATE (tab);
   tab->priv->save_credentials = FALSE;
   tab->priv->keyring_item_id = 0;
@@ -914,6 +916,7 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
   gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), suggested_filename->str);
   g_string_free (suggested_filename, TRUE);
 
+  /* FIXME: Assumes that the PNG format is always supported by GdkPixbuf. */
   formats = get_supported_image_formats ();
   for (l = formats; l; l = l->next)
     {
@@ -996,20 +999,19 @@ vinagre_tab_get_initialized_actions (VinagreTab *tab)
 }
 
 static void
-free_actions (gpointer data, gpointer user_data)
+_free_action (gpointer data)
 {
   VinagreTabUiAction *action = (VinagreTabUiAction *)data;
 
   g_strfreev (action->paths);
   g_object_unref (action->action);
-  g_free (action);
+  g_slice_free (VinagreTabUiAction, action);
 }
 
 void
 vinagre_tab_free_actions (GSList *actions)
 {
-  g_slist_foreach (actions, (GFunc) free_actions, NULL);
-  g_slist_free (actions);
+  g_slist_free_full (actions, _free_action);
 }
 
 const gchar *
